@@ -127,6 +127,26 @@ class Settings:
     find_dialog_state = None
     """Find dialog state - needs to be stored when dialog is closed"""
 
+    encodings = (
+        "ascii", "big5", "big5hkscs", "cp037", "cp424", "cp437",
+        "cp500", "cp720", "cp737", "cp775", "cp850", "cp852", "cp855", "cp856",
+        "cp857", "cp858", "cp860", "cp861", "cp862", "cp863", "cp864", "cp865",
+        "cp866", "cp869", "cp874", "cp875", "cp932", "cp949", "cp950",
+        "cp1006", "cp1026", "cp1140", "cp1250", "cp1251", "cp1252", "cp1253",
+        "cp1254", "cp1255", "cp1256", "cp1257", "cp1258", "euc-jp",
+        "euc-jis-2004", "euc-jisx0213", "euc-kr", "gb2312", "gbk", "gb18030",
+        "hz", "iso2022-jp", "iso2022-jp-1", "iso2022-jp-2", "iso2022-jp-2004",
+        "iso2022-jp-3", "iso2022-jp-ext", "iso2022-kr", "latin-1", "iso8859-2",
+        "iso8859-3", "iso8859-4", "iso8859-5", "iso8859-6", "iso8859-7",
+        "iso8859-8", "iso8859-9", "iso8859-10", "iso8859-13", "iso8859-14",
+        "iso8859-15", "iso8859-16", "johab", "koi8-r", "koi8-u",
+        "mac-cyrillic", "mac-greek", "mac-iceland", "mac-latin2", "mac-roman",
+        "mac-turkish", "ptcp154", "shift-jis", "shift-jis-2004",
+        "shift-jisx0213", "utf-32", "utf-32-be", "utf-32-le", "utf-16",
+        "utf-16-be", "utf-16-le", "utf-7", "utf-8", "utf-8-sig",
+    )
+    """Encodings for importing files (e.g. CSV or SVG)"""
+
     sniff_size = 65536
     """Number of bytes for csv sniffer
        sniff_size should be larger than 1st+2nd line
@@ -155,8 +175,7 @@ class Settings:
         """
 
         if not hasattr(self, key):
-            raise AttributeError("{self} has no attribute {key}.".format(
-                                 self=self, key=key))
+            raise AttributeError(f"{self} has no attribute {key}.")
         super().__setattr__(key, value)
 
     def add_to_file_history(self, filename: Path):
@@ -171,6 +190,8 @@ class Settings:
         self.file_history = self.file_history[:self.max_file_history]
 
     def reset(self):
+        """Reset to defaults"""
+
         cls_attrs = (attr for attr in dir(self)
                      if (not attr.startswith("__")
                          and attr not in ("reset", "parent", "save",
@@ -261,7 +282,8 @@ class Settings:
             if attr is None:
                 attr = setting_name
             if mapper is None:
-                def mapper(x): return x
+                def mapper(x):
+                    return x
             setattr(self, attr, mapper(value))
 
         # Application state
